@@ -1,3 +1,6 @@
+// SPDX-License-Identifier: Apache-2.0
+// Copyright Authors of K9s
+
 package config
 
 import "github.com/derailed/k9s/internal/client"
@@ -9,8 +12,8 @@ const DefaultPFAddress = "localhost"
 type Cluster struct {
 	Namespace          *Namespace    `yaml:"namespace"`
 	View               *View         `yaml:"view"`
+	Skin               string        `yaml:"skin,omitempty"`
 	FeatureGates       *FeatureGates `yaml:"featureGates"`
-	ShellPod           *ShellPod     `yaml:"shellPod"`
 	PortForwardAddress string        `yaml:"portForwardAddress"`
 }
 
@@ -21,7 +24,6 @@ func NewCluster() *Cluster {
 		View:               NewView(),
 		PortForwardAddress: DefaultPFAddress,
 		FeatureGates:       NewFeatureGates(),
-		ShellPod:           NewShellPod(),
 	}
 }
 
@@ -46,9 +48,4 @@ func (c *Cluster) Validate(conn client.Connection, ks KubeSettings) {
 		c.View = NewView()
 	}
 	c.View.Validate()
-
-	if c.ShellPod == nil {
-		c.ShellPod = NewShellPod()
-	}
-	c.ShellPod.Validate(conn, ks)
 }
