@@ -1,3 +1,6 @@
+// SPDX-License-Identifier: Apache-2.0
+// Copyright Authors of K9s
+
 package config
 
 import (
@@ -17,7 +20,7 @@ const (
 	DefaultFileMod os.FileMode = 0600
 )
 
-var invalidPathCharsRX = regexp.MustCompile(`[:]+`)
+var invalidPathCharsRX = regexp.MustCompile(`[:/]+`)
 
 // SanitizeFilename sanitizes the dump filename.
 func SanitizeFilename(name string) string {
