@@ -1,3 +1,6 @@
+// SPDX-License-Identifier: Apache-2.0
+// Copyright Authors of K9s
+
 package dao
 
 import (
@@ -155,6 +158,8 @@ func (n *Node) List(ctx context.Context, ns string) ([]runtime.Object, error) {
 		nmx, _ = client.DialMetrics(n.Client()).FetchNodesMetricsMap(ctx)
 	}
 
+	shouldCountPods, _ := ctx.Value(internal.KeyPodCounting).(bool)
+
 	res := make([]runtime.Object, 0, len(oo))
 	for _, o := range oo {
 		u, ok := o.(*unstructured.Unstructured)
@@ -164,9 +169,12 @@ func (n *Node) List(ctx context.Context, ns string) ([]runtime.Object, error) {
 
 		fqn := extractFQN(o)
 		_, name := client.Namespaced(fqn)
-		podCount, err := n.CountPods(name)
-		if err != nil {
-			log.Error().Err(err).Msgf("unable to get pods count for %s", name)
+		podCount := -1
+		if shouldCountPods {
+			podCount, err = n.CountPods(name)
+			if err != nil {
+				log.Error().Err(err).Msgf("unable to get pods count for %s", name)
+			}
 		}
 		res = append(res, &render.NodeWithMetrics{
 			Raw:      u,
