@@ -1,8 +1,12 @@
+// SPDX-License-Identifier: Apache-2.0
+// Copyright Authors of K9s
+
 package model
 
 import (
 	"github.com/derailed/k9s/internal/dao"
 	"github.com/derailed/k9s/internal/render"
+	"github.com/derailed/k9s/internal/render/helm"
 	"github.com/derailed/k9s/internal/xray"
 )
 
@@ -22,19 +26,22 @@ var Registry = map[string]ResourceMeta{
 		DAO: &dao.Pulse{},
 	},
 	"helm": {
-		DAO:      &dao.Helm{},
-		Renderer: &render.Helm{},
+		DAO:      &dao.HelmChart{},
+		Renderer: &helm.Chart{},
+	},
+	"helm-history": {
+		DAO:      &dao.HelmHistory{},
+		Renderer: &helm.History{},
 	},
-	// BOZO!! revamp with latest...
-	// "openfaas": {
-	// 	DAO:      &dao.OpenFaas{},
-	// 	Renderer: &render.OpenFaas{},
-	// },
 	"containers": {
 		DAO:          &dao.Container{},
 		Renderer:     &render.Container{},
 		TreeRenderer: &xray.Container{},
 	},
+	"scans": {
+		DAO:      &dao.ImageScan{},
+		Renderer: &render.ImageScan{},
+	},
 	"contexts": {
 		DAO:      &dao.Context{},
 		Renderer: &render.Context{},
