@@ -1,3 +1,6 @@
+// SPDX-License-Identifier: Apache-2.0
+// Copyright Authors of K9s
+
 package model
 
 import (
@@ -36,8 +39,8 @@ func NewValues(gvr client.GVR, path string) *Values {
 	}
 }
 
-func getHelmDao() *dao.Helm {
-	return Registry["helm"].DAO.(*dao.Helm)
+func getHelmDao() *dao.HelmChart {
+	return Registry["helm"].DAO.(*dao.HelmChart)
 }
 
 func getValues(path string, allValues bool) []string {
@@ -48,6 +51,11 @@ func getValues(path string, allValues bool) []string {
 	return strings.Split(string(vals), "\n")
 }
 
+// GVR returns the resource gvr.
+func (v *Values) GVR() client.GVR {
+	return v.gvr
+}
+
 // ToggleValues toggles between user supplied values and computed values.
 func (v *Values) ToggleValues() {
 	v.allValues = !v.allValues
