@@ -1,3 +1,6 @@
+// SPDX-License-Identifier: Apache-2.0
+// Copyright Authors of K9s
+
 package render
 
 import (
@@ -32,7 +35,7 @@ func (CustomResourceDefinition) Header(string) Header {
 func (c CustomResourceDefinition) Render(o interface{}, ns string, r *Row) error {
 	raw, ok := o.(*unstructured.Unstructured)
 	if !ok {
-		return fmt.Errorf("Expected CustomResourceDefinition, but got %T", o)
+		return fmt.Errorf("expected CustomResourceDefinition, but got %T", o)
 	}
 
 	var crd v1.CustomResourceDefinition
@@ -60,8 +63,8 @@ func (c CustomResourceDefinition) Render(o interface{}, ns string, r *Row) error
 		crd.GetName(),
 		naStrings(versions),
 		mapToIfc(crd.GetLabels()),
-		asStatus(c.diagnose(crd.GetName(), crd.Spec.Versions)),
-		toAge(crd.GetCreationTimestamp()),
+		AsStatus(c.diagnose(crd.GetName(), crd.Spec.Versions)),
+		ToAge(crd.GetCreationTimestamp()),
 	}
 
 	return nil
@@ -84,7 +87,7 @@ func (c CustomResourceDefinition) diagnose(n string, vv []v1.CustomResourceDefin
 			if v.DeprecationWarning != nil {
 				ee = append(ee, fmt.Errorf("%s", *v.DeprecationWarning))
 			} else {
-				ee = append(ee, fmt.Errorf("%s[%s] is deprecated!", n, v.Name))
+				ee = append(ee, fmt.Errorf("%s[%s] is deprecated", n, v.Name))
 			}
 		}
 	}
