@@ -1,3 +1,6 @@
+// SPDX-License-Identifier: Apache-2.0
+// Copyright Authors of K9s
+
 package render
 
 import (
@@ -12,10 +15,17 @@ import (
 	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
 	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/apimachinery/pkg/runtime/schema"
-	"k8s.io/kubernetes/pkg/util/node"
 	mv1beta1 "k8s.io/metrics/pkg/apis/metrics/v1beta1"
 
 	"github.com/derailed/k9s/internal/client"
+	"github.com/derailed/k9s/internal/vul"
+)
+
+const (
+	// NodeUnreachablePodReason is reason and message set on a pod when its state
+	// cannot be confirmed as kubelet is unresponsive on the node it is (was) running.
+	NodeUnreachablePodReason = "NodeLost" // k8s.io/kubernetes/pkg/util/node.NodeUnreachablePodReason
+	vulIdx                   = 2
 )
 
 const (
@@ -75,13 +85,18 @@ func (p Pod) ColorerFunc() ColorerFunc {
 
 // Header returns a header row.
 func (Pod) Header(ns string) Header {
-	return Header{
+	h := Header{
 		HeaderColumn{Name: "NAMESPACE"},
 		HeaderColumn{Name: "NAME"},
+		HeaderColumn{Name: "VS"},
 		HeaderColumn{Name: "PF"},
 		HeaderColumn{Name: "READY"},
-		HeaderColumn{Name: "RESTARTS", Align: tview.AlignRight},
 		HeaderColumn{Name: "STATUS"},
+		HeaderColumn{Name: "RESTARTS", Align: tview.AlignRight},
+		HeaderColumn{Name: "IP"},
+		HeaderColumn{Name: "NODE"},
+		HeaderColumn{Name: "NOMINATED NODE", Wide: true},
+		HeaderColumn{Name: "READINESS GATES", Wide: true},
 		HeaderColumn{Name: "CPU", Align: tview.AlignRight, MX: true},
 		HeaderColumn{Name: "MEM", Align: tview.AlignRight, MX: true},
 		HeaderColumn{Name: "CPU/R:L", Align: tview.AlignRight, Wide: true},
@@ -90,15 +105,27 @@ func (Pod) Header(ns string) Header {
 		HeaderColumn{Name: "%CPU/L", Align: tview.AlignRight, MX: true},
 		HeaderColumn{Name: "%MEM/R", Align: tview.AlignRight, MX: true},
 		HeaderColumn{Name: "%MEM/L", Align: tview.AlignRight, MX: true},
-		HeaderColumn{Name: "IP"},
-		HeaderColumn{Name: "NODE"},
 		HeaderColumn{Name: "QOS", Wide: true},
 		HeaderColumn{Name: "LABELS", Wide: true},
 		HeaderColumn{Name: "VALID", Wide: true},
-		HeaderColumn{Name: "NOMINATED NODE", Wide: true},
-		HeaderColumn{Name: "READINESS GATES", Wide: true},
 		HeaderColumn{Name: "AGE", Time: true},
 	}
+	if vul.ImgScanner == nil {
+		h = append(h[:vulIdx], h[vulIdx+1:]...)
+	}
+
+	return h
+}
+
+// ExtractImages returns a collection of container images.
+// !!BOZO!! If this has any legs?? enable scans on other container types.
+func ExtractImages(spec *v1.PodSpec) []string {
+	ii := make([]string, 0, len(spec.Containers))
+	for _, c := range spec.Containers {
+		ii = append(ii, c.Image)
+	}
+
+	return ii
 }
 
 // Render renders a K8s resource to screen.
@@ -113,8 +140,10 @@ func (p Pod) Render(o interface{}, ns string, row *Row) error {
 		return err
 	}
 
-	ss := po.Status.ContainerStatuses
-	cr, _, rc := p.Statuses(ss)
+	ics := po.Status.InitContainerStatuses
+	_, _, irc := p.Statuses(ics)
+	cs := po.Status.ContainerStatuses
+	cr, _, rc := p.Statuses(cs)
 
 	c, r := p.gatherPodMX(&po, pwm.MX)
 	phase := p.Phase(&po)
@@ -122,10 +151,15 @@ func (p Pod) Render(o interface{}, ns string, row *Row) error {
 	row.Fields = Fields{
 		po.Namespace,
 		po.ObjectMeta.Name,
+		computeVulScore(&po.Spec),
 		"●",
 		strconv.Itoa(cr) + "/" + strconv.Itoa(len(po.Spec.Containers)),
-		strconv.Itoa(rc),
 		phase,
+		strconv.Itoa(rc + irc),
+		na(po.Status.PodIP),
+		na(po.Spec.NodeName),
+		asNominated(po.Status.NominatedNodeName),
+		asReadinessGate(po),
 		toMc(c.cpu),
 		toMi(c.mem),
 		toMc(r.cpu) + ":" + toMc(r.lcpu),
@@ -134,14 +168,13 @@ func (p Pod) Render(o interface{}, ns string, row *Row) error {
 		client.ToPercentageStr(c.cpu, r.lcpu),
 		client.ToPercentageStr(c.mem, r.mem),
 		client.ToPercentageStr(c.mem, r.lmem),
-		na(po.Status.PodIP),
-		na(po.Spec.NodeName),
 		p.mapQOS(po.Status.QOSClass),
 		mapToStr(po.Labels),
-		asStatus(p.diagnose(phase, cr, len(ss))),
-		asNominated(po.Status.NominatedNodeName),
-		asReadinessGate(po),
-		toAge(po.GetCreationTimestamp()),
+		AsStatus(p.diagnose(phase, cr, len(cs))),
+		ToAge(po.GetCreationTimestamp()),
+	}
+	if vul.ImgScanner == nil {
+		row.Fields = append(row.Fields[:vulIdx], row.Fields[vulIdx+1:]...)
 	}
 
 	return nil
@@ -306,7 +339,7 @@ func (*Pod) Statuses(ss []v1.ContainerStatus) (cr, ct, rc int) {
 func (p *Pod) Phase(po *v1.Pod) string {
 	status := string(po.Status.Phase)
 	if po.Status.Reason != "" {
-		if po.DeletionTimestamp != nil && po.Status.Reason == "NodeLost" {
+		if po.DeletionTimestamp != nil && po.Status.Reason == NodeUnreachablePodReason {
 			return "Unknown"
 		}
 		status = po.Status.Reason
@@ -453,7 +486,7 @@ func PodStatus(pod *v1.Pod) string {
 		}
 	}
 
-	if pod.DeletionTimestamp != nil && pod.Status.Reason == node.NodeUnreachablePodReason {
+	if pod.DeletionTimestamp != nil && pod.Status.Reason == NodeUnreachablePodReason {
 		reason = PhaseUnknown
 	} else if pod.DeletionTimestamp != nil {
 		reason = PhaseTerminating
