@@ -1,3 +1,6 @@
+// SPDX-License-Identifier: Apache-2.0
+// Copyright Authors of K9s
+
 package render
 
 import (
@@ -5,6 +8,7 @@ import (
 	"strconv"
 
 	"github.com/derailed/k9s/internal/client"
+	"github.com/derailed/k9s/internal/vul"
 	appsv1 "k8s.io/api/apps/v1"
 	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
 	"k8s.io/apimachinery/pkg/runtime"
@@ -17,9 +21,10 @@ type StatefulSet struct {
 
 // Header returns a header row.
 func (StatefulSet) Header(ns string) Header {
-	return Header{
+	h := Header{
 		HeaderColumn{Name: "NAMESPACE"},
 		HeaderColumn{Name: "NAME"},
+		HeaderColumn{Name: "VS"},
 		HeaderColumn{Name: "READY"},
 		HeaderColumn{Name: "SELECTOR", Wide: true},
 		HeaderColumn{Name: "SERVICE"},
@@ -29,13 +34,18 @@ func (StatefulSet) Header(ns string) Header {
 		HeaderColumn{Name: "VALID", Wide: true},
 		HeaderColumn{Name: "AGE", Time: true},
 	}
+	if vul.ImgScanner == nil {
+		h = append(h[:vulIdx], h[vulIdx+1:]...)
+	}
+
+	return h
 }
 
 // Render renders a K8s resource to screen.
 func (s StatefulSet) Render(o interface{}, ns string, r *Row) error {
 	raw, ok := o.(*unstructured.Unstructured)
 	if !ok {
-		return fmt.Errorf("Expected StatefulSet, but got %T", o)
+		return fmt.Errorf("expected StatefulSet, but got %T", o)
 	}
 	var sts appsv1.StatefulSet
 	err := runtime.DefaultUnstructuredConverter.FromUnstructured(raw.Object, &sts)
@@ -47,14 +57,18 @@ func (s StatefulSet) Render(o interface{}, ns string, r *Row) error {
 	r.Fields = Fields{
 		sts.Namespace,
 		sts.Name,
+		computeVulScore(&sts.Spec.Template.Spec),
 		strconv.Itoa(int(sts.Status.ReadyReplicas)) + "/" + strconv.Itoa(int(sts.Status.Replicas)),
 		asSelector(sts.Spec.Selector),
 		na(sts.Spec.ServiceName),
 		podContainerNames(sts.Spec.Template.Spec, true),
 		podImageNames(sts.Spec.Template.Spec, true),
 		mapToStr(sts.Labels),
-		asStatus(s.diagnose(sts.Status.Replicas, sts.Status.ReadyReplicas)),
-		toAge(sts.GetCreationTimestamp()),
+		AsStatus(s.diagnose(sts.Status.Replicas, sts.Status.ReadyReplicas)),
+		ToAge(sts.GetCreationTimestamp()),
+	}
+	if vul.ImgScanner == nil {
+		r.Fields = append(r.Fields[:vulIdx], r.Fields[vulIdx+1:]...)
 	}
 
 	return nil
