@@ -1,3 +1,6 @@
+// SPDX-License-Identifier: Apache-2.0
+// Copyright Authors of K9s
+
 package view
 
 import (
@@ -20,6 +23,7 @@ import (
 	"github.com/derailed/k9s/internal/model"
 	"github.com/derailed/k9s/internal/ui"
 	"github.com/derailed/k9s/internal/ui/dialog"
+	"github.com/derailed/k9s/internal/vul"
 	"github.com/derailed/k9s/internal/watch"
 	"github.com/derailed/tcell/v2"
 	"github.com/derailed/tview"
@@ -117,9 +121,28 @@ func (a *App) Init(version string, rate int) error {
 	a.layout(ctx)
 	a.initSignals()
 
+	if a.Config.K9s.EnableImageScan {
+		a.initImgScanner(version)
+	}
+
 	return nil
 }
 
+func (a *App) stopImgScanner() {
+	if vul.ImgScanner != nil {
+		vul.ImgScanner.Stop()
+	}
+}
+
+func (a *App) initImgScanner(version string) {
+	defer func(t time.Time) {
+		log.Debug().Msgf("Scanner init time %s", time.Since(t))
+	}(time.Now())
+
+	vul.ImgScanner = vul.NewImageScanner()
+	go vul.ImgScanner.Init("k9s", version)
+}
+
 func (a *App) layout(ctx context.Context) {
 	flash := ui.NewFlash(a.App)
 	go flash.Watch(ctx, a.Flash().Channel())
@@ -148,6 +171,11 @@ func (a *App) initSignals() {
 }
 
 func (a *App) suggestCommand() model.SuggestionFunc {
+	contextNames, err := a.contextNames()
+	if err != nil {
+		log.Error().Err(err).Msg("failed to list contexts")
+	}
+
 	return func(s string) (entries sort.StringSlice) {
 		if s == "" {
 			if a.cmdHistory.Empty() {
@@ -158,13 +186,17 @@ func (a *App) suggestCommand() model.SuggestionFunc {
 
 		s = strings.ToLower(s)
 		for _, k := range a.command.alias.Aliases.Keys() {
-			if k == s {
-				continue
-			}
-			if strings.HasPrefix(k, s) {
-				entries = append(entries, strings.Replace(k, s, "", 1))
+			if suggest, ok := shouldAddSuggest(s, k); ok {
+				entries = append(entries, suggest)
 			}
 		}
+
+		namespaceNames, err := a.namespaceNames()
+		if err != nil {
+			log.Error().Err(err).Msg("failed to list namespaces")
+		}
+
+		entries = append(entries, suggestSubCommand(s, namespaceNames, contextNames)...)
 		if len(entries) == 0 {
 			return nil
 		}
@@ -173,6 +205,32 @@ func (a *App) suggestCommand() model.SuggestionFunc {
 	}
 }
 
+func (a *App) namespaceNames() ([]string, error) {
+	namespaces, err := a.factory.Client().ValidNamespaces()
+	if err != nil {
+		return nil, err
+	}
+
+	namespaceNames := make([]string, 0, len(namespaces))
+	for _, namespace := range namespaces {
+		namespaceNames = append(namespaceNames, namespace.Name)
+	}
+	return namespaceNames, nil
+}
+
+func (a *App) contextNames() ([]string, error) {
+	contexts, err := a.factory.Client().Config().Contexts()
+	if err != nil {
+		return nil, err
+	}
+
+	contextNames := make([]string, 0, len(contexts))
+	for ctxName := range contexts {
+		contextNames = append(contextNames, ctxName)
+	}
+	return contextNames, nil
+}
+
 func (a *App) keyboard(evt *tcell.EventKey) *tcell.EventKey {
 	if k, ok := a.HasAction(ui.AsKey(evt)); ok && !a.Content.IsTopDialog() {
 		return k.Action(evt)
@@ -405,6 +463,7 @@ func (a *App) switchContext(name string) error {
 		ns, err := a.Conn().Config().CurrentNamespaceName()
 		if err != nil {
 			log.Warn().Msg("No namespace specified in context. Using K9s config")
+			ns = a.Config.ActiveNamespace()
 		}
 		a.initFactory(ns)
 
@@ -453,6 +512,8 @@ func (a *App) BailOut() {
 	if err := nukeK9sShell(a); err != nil {
 		log.Error().Err(err).Msgf("nuking k9s shell pod")
 	}
+
+	a.stopImgScanner()
 	a.factory.Terminate()
 	a.App.BailOut()
 }
@@ -602,12 +663,11 @@ func (a *App) dirCmd(path string) error {
 }
 
 func (a *App) helpCmd(evt *tcell.EventKey) *tcell.EventKey {
-	top := a.Content.Top()
-
-	if a.CmdBuff().InCmdMode() || (top != nil && top.InCmdMode()) {
+	if evt != nil && evt.Rune() == '?' && a.Prompt().InCmdMode() {
 		return evt
 	}
 
+	top := a.Content.Top()
 	if top != nil && top.Name() == "help" {
 		a.Content.Pop()
 		return nil
@@ -617,6 +677,7 @@ func (a *App) helpCmd(evt *tcell.EventKey) *tcell.EventKey {
 		a.Flash().Err(err)
 	}
 
+	a.Prompt().Deactivate()
 	return nil
 }
 
@@ -647,8 +708,7 @@ func (a *App) gotoResource(cmd, path string, clearStack bool) {
 func (a *App) inject(c model.Component, clearStack bool) error {
 	ctx := context.WithValue(context.Background(), internal.KeyApp, a)
 	if err := c.Init(ctx); err != nil {
-		log.Error().Err(err).Msgf("component init failed for %q", c.Name())
-		//dialog.ShowError(a.Styles.Dialog(), a.Content.Pages, err.Error())
+		log.Error().Err(err).Msgf("Component init failed for %q", c.Name())
 		return err
 	}
 	if clearStack {
@@ -667,3 +727,45 @@ func (a *App) clusterInfo() *ClusterInfo {
 func (a *App) statusIndicator() *ui.StatusIndicator {
 	return a.Views()["statusIndicator"].(*ui.StatusIndicator)
 }
+
+// ----------------------------------------------------------------------------
+// Helpers
+
+func suggestSubCommand(command string, namespaces, contexts []string) []string {
+	cmds := strings.Fields(command)
+	if len(cmds[0]) == 0 || len(cmds) != 2 {
+		return nil
+	}
+
+	var suggests []string
+	switch strings.ToLower(cmds[0]) {
+	case "cow", "q", "q!", "qa", "Q", "quit", "?", "h", "help", "a", "alias", "x", "xray", "dir":
+		return nil // ignore special commands
+	case "ctx", "context", "contexts":
+		for _, ctxName := range contexts {
+			if suggest, ok := shouldAddSuggest(cmds[1], ctxName); ok {
+				suggests = append(suggests, suggest)
+			}
+		}
+	default:
+		if suggest, ok := shouldAddSuggest(cmds[1], client.NamespaceAll); ok {
+			suggests = append(suggests, suggest)
+		}
+
+		for _, ns := range namespaces {
+			if suggest, ok := shouldAddSuggest(cmds[1], ns); ok {
+				suggests = append(suggests, suggest)
+			}
+		}
+	}
+
+	return suggests
+}
+
+func shouldAddSuggest(command, suggest string) (string, bool) {
+	if command != suggest && strings.HasPrefix(suggest, command) {
+		return strings.TrimPrefix(suggest, command), true
+	}
+
+	return "", false
+}
