@@ -1,3 +1,6 @@
+// SPDX-License-Identifier: Apache-2.0
+// Copyright Authors of K9s
+
 package view
 
 import (
@@ -63,6 +66,10 @@ func (s *Service) showPods(a *App, _ ui.Tabular, gvr, path string) {
 		a.Flash().Warnf("No matching pods. Service %s is an external service.", path)
 		return
 	}
+	if svc.Spec.Selector == nil {
+		a.Flash().Warnf("No matching pods. Service %s does not provide any selectors", path)
+		return
+	}
 
 	showPodsWithLabels(a, path, svc.Spec.Selector)
 }
