@@ -1,3 +1,6 @@
+// SPDX-License-Identifier: Apache-2.0
+// Copyright Authors of K9s
+
 package view
 
 import (
@@ -157,7 +160,7 @@ func (x *Xray) refreshActions() {
 		aa[tcell.KeyCtrlD] = ui.NewKeyAction("Delete", x.deleteCmd, true)
 	}
 	if !dao.IsK9sMeta(x.meta) {
-		aa[ui.KeyY] = ui.NewKeyAction("YAML", x.viewCmd, true)
+		aa[ui.KeyY] = ui.NewKeyAction(yamlAction, x.viewCmd, true)
 		aa[ui.KeyD] = ui.NewKeyAction("Describe", x.describeCmd, true)
 	}
 
@@ -262,7 +265,7 @@ func (x *Xray) showLogs(spec *xray.NodeSpec, prev bool) {
 	}
 
 	ns, _ := client.Namespaced(path)
-	_, err := x.app.factory.CanForResource(ns, "v1/pods", client.MonitorAccess)
+	_, err := x.app.factory.CanForResource(ns, "v1/pods", client.ListAccess)
 	if err != nil {
 		x.app.Flash().Err(err)
 		return
@@ -338,7 +341,7 @@ func (x *Xray) viewCmd(evt *tcell.EventKey) *tcell.EventKey {
 		return nil
 	}
 
-	details := NewDetails(x.app, "YAML", spec.Path(), true).Update(raw)
+	details := NewDetails(x.app, yamlAction, spec.Path(), contentYAML, true).Update(raw)
 	if err := x.app.inject(details, false); err != nil {
 		x.app.Flash().Err(err)
 	}
@@ -388,7 +391,7 @@ func (x *Xray) describe(gvr, path string) {
 		return
 	}
 
-	details := NewDetails(x.app, "Describe", path, true).Update(yaml)
+	details := NewDetails(x.app, "Describe", path, contentYAML, true).Update(yaml)
 	if err := x.app.inject(details, false); err != nil {
 		x.app.Flash().Err(err)
 	}
